@@ -48,6 +48,19 @@ class CAccessor:
             ok = False
         return ok
 
+    @staticmethod
+    def __soft_validate_iso(row, iso_col='iso', month_col=None):
+        try:
+            if month_col is not None:
+                _ = Country.from_iso(int(row[iso_col]), int(row[month_col]))
+            else:
+                _ = Country.from_iso(int(row[iso_col]))
+            ok = True
+        except ValueError:
+            ok = False
+        return ok
+
+
     @staticmethod
     def __soft_validate_gw(row, gw_col='gwcode', month_col=None):
         try:
@@ -61,7 +74,14 @@ class CAccessor:
         return ok
 
     @classmethod
-    def soft_validate_gwcode(self, df, gw_col='gwcode', month_col=None):
+    def soft_validate_iso(cls, df, iso_col='iso', month_col=None):
+        z = df.copy()
+        soft_validator = partial(CAccessor.__soft_validate_iso, iso_col=iso_col, month_col=month_col)
+        z['valid_id'] = df.apply(soft_validator, axis=1)
+        return z
+
+    @classmethod
+    def soft_validate_gwcode(cls, df, gw_col='gwcode', month_col=None):
         z = df.copy()
         soft_validator = partial(CAccessor.__soft_validate_gw, gw_col=gw_col, month_col=month_col)
         z['valid_id'] = df.apply(soft_validator, axis=1)
